@@ -22,9 +22,8 @@
 #' and import of spectral metadata.
 #'
 #' @examples
-#' rspecdata <- getspec(system.file("testdata", package = "pavo"), ext = "ttt", lim = c(400, 700))
+#' rspecdata <- getspec(system.file("testdata", package = "lightr"), ext = "ttt", lim = c(400, 700))
 #' head(rspecdata)
-#'
 #' @author Rafael Maia \email{rm72@@zips.uakron.edu}
 #' @author Hugo Gruson \email{hugo.gruson+R@@normalesup.org}
 #'
@@ -35,14 +34,16 @@
 getspec <- function(where = getwd(), ext = "txt", lim = c(300, 700), decimal = ".",
                     sep = NULL, subdir = FALSE, subdir.names = FALSE,
                     cores = NULL, ignore.case = TRUE) {
-
   if (!missing(cores)) {
-    warning("'cores' argument is deprecated. See ?future::plan for more info ",
-            "about how you can choose your parallelisation strategy.")
+    warning(
+      "'cores' argument is deprecated. See ?future::plan for more info ",
+      "about how you can choose your parallelisation strategy."
+    )
   }
 
-  lr_get_spec(where = where, ext = ext, lim = lim, decimal = decimal, sep = sep,
-              subdir = subdir, subdir.names = subdir.names,
-              ignore.case = ignore.case)
-
+  lr_get_spec(
+    where = where, ext = ext, lim = lim, decimal = decimal, sep = sep,
+    subdir = subdir, subdir.names = subdir.names,
+    ignore.case = ignore.case
+  )
 }
