@@ -1,5 +1,3 @@
-context("coldist")
-
 test_that("Errors", {
   data(flowers)
 
@@ -64,9 +62,9 @@ test_that("Equivalent", {
 test_that("Options", {
   data(sicalis)
 
-  expect_length(coldist(vismodel(sicalis, achromatic = "bt.dc", qcatch = "fi", relative = FALSE),
+  expect_length(coldist(vismodel(sicalis, achromatic = "bt.dc", qcatch = "fi", illum = 1000, relative = FALSE),
     noise = "quantum",
-    achro = TRUE
+    achromatic = TRUE
   ), 4)
 })
 
@@ -89,17 +87,15 @@ test_that("jnd transform", {
 })
 
 test_that("Output", {
-  data(flowers)
-
   # Maximum possible unweighted Euclidean distances
   di <- data.frame(s = c(0, 1), l = c(1, 0))
-  expect_equal(coldist(colspace(di, space = "di"))["dS"], (1 / sqrt(2)) * 2, check.attributes = FALSE)
+  expect_equal(coldist(colspace(di, space = "di"))[["dS"]], (1 / sqrt(2)) * 2)
 
   tri <- data.frame(s = c(0, 0), m = c(0, 1), l = c(1, 0))
-  expect_equal(coldist(colspace(tri, space = "tri"))["dS"], (1 / sqrt(2)) * 2, check.attributes = FALSE)
+  expect_equal(coldist(colspace(tri, space = "tri"))[["dS"]], (1 / sqrt(2)) * 2)
 
   tetra <- data.frame(u = c(0, 1), s = c(0, 0), m = c(0, 0), l = c(1, 0))
-  expect_equal(coldist(colspace(tetra, space = "tcs"))["dS"], (sqrt(3) / (2 * sqrt(2))) * 2, check.attributes = FALSE)
+  expect_equal(coldist(colspace(tetra, space = "tcs"))[["dS"]], (sqrt(3) / (2 * sqrt(2))) * 2)
 })
 
 test_that("bootcoldist", {
@@ -108,5 +104,10 @@ test_that("bootcoldist", {
 
   vm <- vismodel(sicalis, visual = "apis", achromatic = "l")
   gr <- gsub("ind..", "", rownames(vm))
-  expect_equal(dim(bootcoldist(vm, by = gr, n = c(1, 2, 3), weber = 0.1, weber.achro = 0.1, cores = 1)), c(3, 6))
+
+  bcd <- expect_warning(
+    bootcoldist(vm, by = gr, n = c(1, 2, 3), weber = 0.1, weber.achro = 0.1),
+    "relative"
+  )
+  expect_equal(dim(bcd), c(3, 6))
 })
