@@ -1,5 +1,3 @@
-context("hashes")
-
 test_that("coldist", {
   skip_on_cran()
 
@@ -36,7 +34,6 @@ test_that("coldist", {
     digest::sha1(coldist(as.matrix(vismodel(flowers, achro = "bt.dc")), qcatch = "Qi", achromatic = TRUE), digits = 4),
     "c6d1989e98abd7772c00475696c6e6dafe0a2e46"
   )
-
 })
 
 test_that("colspace", {
@@ -47,19 +44,19 @@ test_that("colspace", {
 
   expect_equal(
     digest::sha1(colspace(vismodel(flowers, visual = "canis", achromatic = "all")), digits = 4),
-    "0e01892cc85af65956927dde880a432cb8ef58f3"
+    "47352906f00a35504177712d772737b33a6ede64"
   ) # dispace
   expect_equal(
     digest::sha1(colspace(vismodel(flowers, visual = "apis", achromatic = "l")), digits = 4),
-    "68e113dd2b4ad1bfb80d236fa64f3b5c97e2b48d"
+    "81aa34c6d3f86e5644f2d2793d03bd14cb7281da"
   ) # trispace
   expect_equal(
     digest::sha1(colspace(vismodel(flowers, visual = "bluetit", achromatic = "ch.dc")), digits = 4),
-    "57cb207e9637250020dabdd0d96570a63025dd36"
+    "56b236d6f0591a25b067009a10dc2d96c3e27c4f"
   ) # tcs
   expect_equal(
     digest::sha1(colspace(vismodel(flowers, visual = "musca", achro = "md.r1"), space = "categorical"), digits = 4),
-    "681486ec527c0f6e50e6dde1e23831f6c407895e"
+    "b20853b3e52a60f2dd17b418a48b681d7f49e7d1"
   ) # categorical
   expect_equal(
     digest::sha1(colspace(vismodel(flowers, visual = "segment", achromatic = "bt.dc"), space = "segment"), digits = 4),
@@ -71,19 +68,19 @@ test_that("colspace", {
   ) # coc
   expect_equal(
     digest::sha1(colspace(vismodel(flowers, visual = "apis", qcatch = "Ei", vonkries = TRUE, relative = FALSE, achromatic = "l"), space = "hexagon"), digits = 4),
-    "2b51da258f4c5bcaf3a8a851e4e13cbd011c400f"
+    "a1fdd24e315413825c94d4caf1164b8be57c8156"
   ) # hexagon
   expect_equal(
     digest::sha1(colspace(vismodel(flowers, visual = "cie10"), space = "ciexyz"), digits = 4),
-    "4738ecfa2f5859134d0578d84bdd103ad7912983"
+    "99684793a0db286562bff697354496ac3ef0abfb"
   ) # ciexyz
   expect_equal(
     digest::sha1(colspace(vismodel(flowers, visual = "cie10"), space = "cielab"), digits = 4),
-    "dfc481f4410e335fd63112db92712e4857f6515e"
+    "55961f7e22403fba0c0c658868918722befb5f2c"
   ) # cielab
   expect_equal(
     digest::sha1(colspace(vismodel(flowers, visual = "cie10"), space = "cielch"), digits = 4),
-    "f4e4cc8da4fdffddc80c51f2f830b88adba3779d"
+    "e0ad250b695e97c9ffb53c0303f19d908e33d033"
   ) # cielch
 
   # sha1() has no method for the 'table' class
@@ -91,8 +88,32 @@ test_that("colspace", {
   #   digest::sha1(summary(colspace(vismodel(flowers, visual = "cie10"), space = "cielch")), digits = 4),
   #   "8d9c05ec7ae28b219c4c56edbce6a721bd68af82"
   # )
-  expect_equivalent(round(sum(summary(colspace(vismodel(flowers)))), 5), 4.08984)
-  expect_equivalent(round(sum(summary(colspace(vismodel(flowers))), by = 3), 5), 7.08984)
+})
+
+test_that("voloverlap()", {
+  skip_on_cran()
+
+  data(sicalis)
+  tcs.sicalis.C <- subset(colspace(vismodel(sicalis)), "C")
+  tcs.sicalis.T <- subset(colspace(vismodel(sicalis)), "T")
+  tcs.sicalis.B <- subset(colspace(vismodel(sicalis)), "B")
+
+  expect_equal(
+    digest::sha1(voloverlap(tcs.sicalis.T, tcs.sicalis.B, type = "convex"), digits = 4),
+    "3717422024683f1e3e1bd8dbfe832b177147afce"
+  )
+
+  expect_equal(
+    digest::sha1(voloverlap(tcs.sicalis.T, tcs.sicalis.C, type = "convex"), digits = 4),
+    "69b323778e83f2e43a91d60326f1e726eb2cd0e4"
+  )
+  voloverlap(tcs.sicalis.T, tcs.sicalis.B, type = "alpha", avalue = 0.5, nsamp = 10000)
+
+  set.seed(20200517)
+  expect_equal(
+    digest::sha1(voloverlap(tcs.sicalis.T, tcs.sicalis.B, type = "alpha", avalue = 0.5, nsamp = 10000), digits = 4),
+    "7932522b35c2c59365fe7c342f367f8ec35f601a"
+  )
 })
 
 test_that("processing & general", {
@@ -101,23 +122,24 @@ test_that("processing & general", {
   library(digest)
 
   # Sensdata
-  expect_equal(
-    digest::sha1(sensdata(illum = "all", bkg = "all", trans = "all"), digits = 4),
-    "4e25ee65b1a5d3a993baf4ba11b6ad7c15348704"
+  expect_known_hash(
+    expect_silent(sensdata(illum = "all", bkg = "all", trans = "all")),
+    "27b20f98dc"
   )
+
   # Peakshape
-  expect_equivalent(
-    digest::sha1(peakshape(flowers, absolute.min = TRUE), digits = 5),
-    "d257957d21449f28fd24a9a0a33220dcd9a371bd"
+  expect_known_hash(
+    expect_silent(peakshape(flowers, absolute.min = TRUE)),
+    "7fbaba1738"
   )
 
   # Merge
   data(teal)
   teal1 <- teal[, c(1, 3:5)]
   teal2 <- teal[, c(1, 2, 6:12)]
-  expect_equal(
-    digest::sha1(merge(teal1, teal2, by = "wl"), digits = 4),
-    "8c0579ca0ebb379ddd163f0b0d1b1c6b21c4c88c"
+  expect_known_hash(
+    expect_silent(merge(teal1, teal2, by = "wl")),
+    "02df3eedf3"
   )
 
   # Subset
@@ -126,7 +148,7 @@ test_that("processing & general", {
   tcs.sicalis <- colspace(vis.sicalis, space = "tcs")
   expect_equal(
     digest::sha1(subset(vis.sicalis, "C"), digits = 4),
-    "d265007e21606280699956c9df106edbababaa76"
+    "93ae671c250d2d4f0f5dcf9e714eb497d8baf74f"
   )
   expect_equal(
     digest::sha1(subset(sicalis, "T", invert = TRUE), digits = 4),
@@ -134,13 +156,13 @@ test_that("processing & general", {
   )
 
   # Summary
-  expect_equal(
-    digest::sha1(summary(teal), digits = 4),
-    "59e740d97537e0b9892a914b489231f7ccbd8517"
+  expect_known_hash(
+    expect_silent(summary(teal)),
+    "c64e1fd403"
   )
-  expect_equal(
-    digest::sha1(summary(sicalis), digits = 4),
-    "a882bdb4bdcda1b95235f02d0783fb705e66b834"
+  expect_known_hash(
+    expect_silent(summary(sicalis)),
+    "66129550f3"
   )
 })
 
@@ -156,11 +178,11 @@ test_that("images", {
 
   expect_equal(
     digest::sha1(summary(papilio), digits = 4),
-    "b133bda5cc2567ff80a35bdb6d1e5b89e87af8a5"
+    "aa1c46d4796c523f51c4e959ac90a692dd8ecfe4"
   )
   expect_equal(
     digest::sha1(summary(snakes), digits = 4),
-    "001fb04576b913633f04ea890edef83b41f07e16"
+    "dd7fc9fd7c41da84c641181a9a3701da74f3c41e"
   )
 })
 
@@ -173,19 +195,19 @@ test_that("vismodel", {
   # Output
   expect_equal(
     digest::sha1(vismodel(flowers, visual = "canis", achromatic = "all", illum = "bluesky"), digits = 4),
-    "d1d8229f54a64ba9d292284e784d196ee6a8021b"
+    "61879badc0cb518ebd8f62f9c8838c7b32cb51ff"
   )
   expect_equal(
     digest::sha1(vismodel(flowers, visual = "apis", qcatch = "fi", achromatic = "ml", scale = 10000), digits = 4),
-    "fc77a98dd6335db3f5ed24bbda148aa39d0bc4f9"
+    "4a3539c87d1c672510df68992b9dc6954337a736"
   )
   expect_equal(
     digest::sha1(vismodel(flowers, visual = "bluetit", achromatic = "ch.dc", trans = "bluetit"), digits = 4),
-    "95275ae220707de802e181798f74f05280a22b93"
+    "fbd9f6b5368f2c81f11ec86a78322e7a14cc7f47"
   )
   expect_equal(
     digest::sha1(vismodel(flowers, visual = "musca", achromatic = "md.r1", relative = FALSE), digits = 4),
-    "9a1b514313bdfc4bb24c87b1098971e401c7dd96"
+    "edcb721c2093c7af40efdae94837c4e01031c8ae"
   )
   expect_equal(
     digest::sha1(vismodel(flowers, visual = "apis", relative = FALSE, qcatch = "Ei", bkg = "green", vonkries = TRUE, achromatic = "l"), digits = 4),
@@ -193,35 +215,35 @@ test_that("vismodel", {
   )
   expect_equal(
     digest::sha1(vismodel(flowers, visual = "cie10"), digits = 4),
-    "04f0a831e1cf7a50137a0f27df2e36d4c899ae41"
+    "fc5f5f2f11fefdcff1bbdd264e28d520f0812712"
   )
 
   # Attributes
   if (getRversion() < "4.0.0") {
     expect_equal(
       digest::sha1(attributes(vismodel(flowers, visual = "canis", achromatic = "all", illum = "bluesky")), digits = 4),
-      "b77b40f7833f88083b7834362b34e80254f1de14"
+      "0f788526e4db68c9921e441066779146f8a4c377"
     )
     expect_equal(
       digest::sha1(attributes(vismodel(flowers, visual = "apis", qcatch = "fi", achromatic = "ml", scale = 10000)), digits = 4),
-      "9a9b662b1dc4c81584d45843905c4daf43355c79"
+      "b9d488a8e36bca04a66e4513e781c21b66c10ce9"
     )
     expect_equal(
       digest::sha1(attributes(vismodel(flowers, visual = "bluetit", achromatic = "ch.dc", trans = "bluetit")), digits = 4),
-      "11f0526bea5e21f5b9c8b910b58e0bbab016b027"
+      "0a3fb5b639d4c4224cf91045d5f8a13cc06f8550"
     )
   } else {
     expect_equal(
       digest::sha1(attributes(vismodel(flowers, visual = "canis", achromatic = "all", illum = "bluesky")), digits = 4),
-      "b984121a82c91aaad824580eab08563eeffb0587"
+      "397eda31c6948884e09ef58a1b8f0ec5d4f3401c"
     )
     expect_equal(
       digest::sha1(attributes(vismodel(flowers, visual = "apis", qcatch = "fi", achromatic = "ml", scale = 10000)), digits = 4),
-      "0fed595d308c8d09234b35b75bd6569f70de9fad"
+      "60744da46c20782fa8af0bf2a93316ed0d2e6e9d"
     )
     expect_equal(
       digest::sha1(attributes(vismodel(flowers, visual = "bluetit", achromatic = "ch.dc", trans = "bluetit")), digits = 4),
-      "760bfeafeea210f8629e126a49a80663f06e8885"
+      "7bca56baefdd2a42fcb59c26614fe0bbec326865"
     )
   }
   # expect_equal(digest::sha1(attributes(vismodel(flowers, visual = 'musca', achro = 'md.r1', relative = FALSE)), digits = 4),  "3fcd2c3eb74ed4e6d2e505b2c207ca558f287d16")
