@@ -1,10 +1,26 @@
-context("voloverlap")
+test_that("Overlap", {
+  data(sicalis)
+  tcs.sicalis.C <- subset(colspace(vismodel(sicalis)), "C")
+  tcs.sicalis.T <- subset(colspace(vismodel(sicalis)), "T")
+  tcs.sicalis.B <- subset(colspace(vismodel(sicalis)), "B")
+
+  expect_equal(sum(voloverlap(tcs.sicalis.T, tcs.sicalis.B, type = "convex")), 0.1972758, tolerance = 1e-5)
+  expect_equal(sum(voloverlap(tcs.sicalis.T, tcs.sicalis.C, type = "convex")), 9.922872e-06, tolerance = 1e-7)
+  expect_equal(sum(voloverlap(tcs.sicalis.T, tcs.sicalis.B, type = "convex")[1:2]), 1.146523e-05, tolerance = 1e-6)
+
+  overlap_alpha <- expect_silent(
+    voloverlap(tcs.sicalis.T, tcs.sicalis.B, type = "alpha", avalue = 0.5)
+  )
+
+  expect_equal(overlap_alpha[[1]], 5.183721e-06, tolerance = 1e-7)
+  expect_equal(overlap_alpha[[2]], 6.231493e-06, tolerance = 1e-7)
+})
 
 test_that("tcs", {
   data(sicalis)
 
   tcs_sicalis <- colspace(vismodel(sicalis))
-  vol_sicalis <- voloverlap(tcs_sicalis, tcs_sicalis)
+  vol_sicalis <- voloverlap(tcs_sicalis, tcs_sicalis, type = "convex")
 
   expect_length(vol_sicalis, 5)
   expect_equal(vol_sicalis$vboth, 1)
@@ -15,10 +31,10 @@ test_that("tri", {
   data(sicalis)
 
   tri_sicalis <- colspace(vismodel(sicalis, visual = "ctenophorus"))
-  vol_sicalis <- voloverlap(tri_sicalis, tri_sicalis)
+  vol_sicalis <- voloverlap(tri_sicalis, tri_sicalis, type = "convex")
 
   expect_length(vol_sicalis, 5)
-  expect_equal(vol_sicalis$overlapvol, 0.00288459)
+  expect_equal(vol_sicalis$overlapvol, 0.00288459, tolerance = 1e-6)
 })
 
 test_that("Dataframe", {
@@ -41,7 +57,7 @@ test_that("Dataframe", {
   colnames(hrep) <- c("x", "y", "z")
   colnames(qux) <- c("x", "y", "z")
 
-  vol <- voloverlap(hrep, qux)
+  vol <- voloverlap(hrep, qux, type = "convex")
 
   expect_length(vol, 5)
   expect_equal(vol$vol1, 2.5 / 3)
@@ -66,8 +82,8 @@ test_that("Symmetric", {
   colnames(hrep) <- c("x", "y", "z")
   colnames(qux) <- c("x", "y", "z")
 
-  vol_hq <- voloverlap(hrep, qux)
-  vol_qh <- voloverlap(qux, hrep)
+  vol_hq <- voloverlap(hrep, qux, type = "convex")
+  vol_qh <- voloverlap(qux, hrep, type = "convex")
 
   expect_equal(vol_hq$overlapvol, vol_qh$overlapvol)
   expect_equal(vol_hq$vsmallest, vol_qh$vsmallest)
@@ -82,5 +98,5 @@ test_that("Plane", {
 
   plane_sicalis <- tcs_sicalis[1:3, ]
 
-  expect_error(suppressWarnings(voloverlap(plane_sicalis, plane_sicalis), "error code 1"))
+  expect_error(suppressWarnings(voloverlap(plane_sicalis, plane_sicalis, type = "convex"), "error code 1"))
 })
